"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

import requests 
from bs4 import BeautifulSoup 
import pandas as pd
import re


# In[2]:


def fb_post(URL):
    r = requests.get(URL) 
    soup = BeautifulSoup(r.content, 'html.parser')
    meta=soup.find_all('meta')
    if len(meta)<8:
        raise Exception('Something Went Wrong !!')
    else:
        for i,j in enumerate(meta):
            if i==6 and str(j).find("og:description"):
                desc=str(j).split('"')[1].replace('\n','').replace('  ',' ')
            elif i==7 and str(j).find("og:image"):
                image=str(j).split('"')[1]
                image=str(image).replace('amp;','')
            elif i==8 and str(j).find("og:url"):
                url=str(j).split('"')[1]
                url=str(url).replace('amp;','')
    return desc,image,url


# In[4]:


# url=input()#'http://www.facebook.com/story.php?story_fbid=3224814467564560&id=1389683114411047&scmts=scwspsdd&extid=mDJbnuN6JNvWLD6J'
# desc,image,url=fb_scrape(url)


# In[5]:


# print(desc)
# print(image)
# print(url)


# In[ ]:


# from selenium import webdriver 
# from time import sleep 
# from webdriver_manager.chrome import ChromeDriverManager 
# from selenium.webdriver.chrome.options import Options 

# usr=input('Enter Email Id:') 
# pwd=input('Enter Password:') 

# driver = webdriver.Chrome(ChromeDriverManager().install()) 
# driver.get('https://www.facebook.com/') 
# print ("Opened facebook") 
# sleep(1) 

# username_box = driver.find_element_by_id('email') 
# username_box.send_keys(usr) 
# print ("Email Id entered") 
# sleep(1) 

# password_box = driver.find_element_by_id('pass') 
# password_box.send_keys(pwd) 
# print ("Password entered") 

# login_box = driver.find_element_by_id('loginbutton') 
# login_box.click() 

# print ("Done") 
# input('Press anything to quit') 
# driver.quit() 
# print("Finished") 




"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

import requests
from PIL import Image
import urllib
from bs4 import BeautifulSoup
import numpy as np
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import time,os
import matplotlib.pyplot as plt


# In[5]:


def insta_profile(chromedriver_path,id_name):
    """
    Chromedriver must be downloaded into device 
    1 chromedriver_path
    2 instagram_profile id_name
    """
    query='https://www.instagram.com/'+id_name+'/'
    browser=webdriver.Chrome(chromedriver_path)
    browser.get(query)
    total_urls=[]
    print("Retrieving ..............")
    n_posts=int(browser.find_element_by_class_name('g47SY ').text)
    iteration=0
    while iteration<=n_posts//24+1:
        page=browser.page_source
        soup=BeautifulSoup(page,'lxml')
        tags=soup.find_all('img',class_='FFVAD')
        track=tags[-1]['src']
        if track not in total_urls:
            total_urls.extend(tags)
        try:
            browser.execute_script("window.scrollTo(0,document.body.scrollHeight)")
            time.sleep(2)
            iteration+=1
        except:
            exit()
    print("Started downloading .........")
    total_urls=set(total_urls)
    for i,url in enumerate(total_urls):
        image=Image.open(urllib.request.urlopen(url['src']))
        try:
            caption=url['alt']
        except:
            caption='No caption'
        try:
            image.save(id_name+'/'+caption[:20]+str(i)+'.jpg')
        except:
            os.makedirs(id_name)
            image.save(id_name+'/'+caption[:20]+'.jpg')
#         print(i)
    return total_urls


# In[8]:


# if __name__=='__main__':
#     try:
#         urls=scrape_images()
#     except:
#         pass
#urls=scrape_images(id_name)


# # image uploder on instagram

# In[66]:


# from instabot import Bot 

# bot = Bot() 
# try:
#     bot.login(username = "+919530450649", password = "Shivam@271882Natural_beauty")
# except:
#     pass
# for img in os.listdir('instagram_images'):
#     image='instagram_images'+'/'+img
#     bot.upload_photo(image, caption ="How cute she is")








from s.altall import altnews
from s.fbsingle import fb_post
from s.instasingle import insta_post
from s.instaall import insta_profile
from s.goimg import google_image 
from s.trading_image import trade
from s.twsingle import twit_post
from s.wpmsg import whatsapp




"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

import requests 
from bs4 import BeautifulSoup 
    
def twit_post(url):
    URL=url.replace('twitter.com','mobile.twitter.com')
    print('Trying with : {}'.format(URL))
    text,image,url='','',''
    with requests.Session() as session:
        try:
            r = requests.get(URL) 
            soup = BeautifulSoup(r.content, 'html.parser')
            text=soup.find('div',attrs={'class':"dir-ltr"})
            text_val=text.text
            url= str(text).split('data-url="')[1].split('"')[0]
            image=soup.find('div',attrs={'class':"media"}).find('img')
            image=str(image).split('src="')[1].split(':small')[0]
        except :
            pass
    return text_val,image,url
#url=input()
#text,image,url=Twitter_scrape(url)
#print(text)
#print(image)
#print(url)



"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

import requests 
from bs4 import BeautifulSoup 
import pandas as pd
import re

# finding url in page
def url_fetch(table):
    links=set()
    for txt in table:
        content=re.findall('https.*',str(txt))
        content=content[0].split("title")[0].replace("\"","").strip()
        links.add(str(content))
    return links
# retrieving url from page
def retrieve_url():
    counter=1
    total_links=[]
    while counter !=249:
        print("Trying to access data of page "+str(counter))
        URL = "https://www.altnews.in/page/"+str(counter)+"/"
        r = requests.get(URL) 
        soup = BeautifulSoup(r.content, 'html.parser') 
        table = soup.find_all('a',attrs={'href'},class_='herald-read-more')
        total_links.append(url_fetch(table))
        counter+=1
    print("Total links found : {} ".format(len(total_links)))
    return total_links


def txt_reterive(text):
    if re.findall('“.*',text) !=-1:
        text=' '.join([t.split('”')[0] for t in re.findall('“.*',text)])
        return text
    else:
        return ''
# synchronize data 
def altnews():
    df=pd.DataFrame(columns=['title','link','date','text','category'])
    count=0
    urls=retrieve_url()
    urls=[url for url_set in urls for url in url_set]
    for url in urls:
        url=str(url).replace('\n','')
        r = requests.get(url) 
        soup = BeautifulSoup(r.content, 'html.parser')
        all_text =soup.find_all('p')
        date=soup.find("span",class_="updated")
        date=date.text
        title=soup.find('h1',class_="entry-title h1")
        title=title.text
        for txt in all_text:
            txt=txt_reterive(txt.text)
            if len(txt)>50:
                df.loc[count]=[title,url,date,txt,'fake']
                print("Writing Row {} data ".format(count))
                count+=1
    return df
#df=altnews()
#df.to_csv('altnews.csv')


# In[6]:







"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

from PIL import Image
import urllib
from bs4 import BeautifulSoup
import numpy as np
from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import time,os


# In[7]:


total_urls=[]
titles=[]
# Saving all exteracted images 

def save_images(urls,titles,query):
    image=[]
    if not os.path.exists(query): # check existence of file 
        os.makedirs(query)
#     n=int(input(" Enter no of titles to download out of "+str(len(urls))+"  : ")) # n topic download 
    for title,urllist in zip(titles[:1],urls[:1]):
        if title !='Home':
            title=str(title['aria-label']) # naming folder based on topic on google 
        print('Downloading  : '+title+' under '+query)
        for i,url in enumerate(urllist):
            if not os.path.exists(query+'/'+title):
                os.makedirs(query+'/'+title)
            try:
                image=Image.open(urllib.request.urlopen(url['src'])) # opening url of image 
            except:
                try:
                    image=Image.open(urllib.request.urlopen(url['data-src']))
                except:
                    pass
            if len(np.array(image))>0:
                try:
                    image.save(query+'/'+title+'/'+url['alt']+str(i)+'.png') # saving image into topic folder 
                except:
                    pass
        print("Saved image : "+str(i))
        
                
# scrolling and going upto last image then scrapping all urls of images 
def images(browser):  # scroll upto end of page for any topic of image 
    found=1
    while(found):
        try:
            count=0
            while(count<6): # button show more results n page consist upto 6 scroll 
                try:
                    browser.execute_script("window.scrollTo(0,document.body.scrollHeight)")
                    time.sleep(5)
                except:
                    pass
                count+=1
            time.sleep(3)
            browser.find_element_by_class_name('mye4qd').click() # clicking on show more results 
            time.sleep(5)
        except:
            found=0
    soup=BeautifulSoup(browser.page_source,'lxml')
    img_urls=[img for img in soup.find_all('img',class_='rg_i Q4LuWd')]
    return img_urls
def clean_garbage_files(query): # cleaning all which are not image from directory 
    root=query
    for folder in os.listdir(root):
        for image in os.listdir(root+'/'+folder):
            if os.stat(root+'/'+folder+'/'+image).st_size <=1:
                try:
                    os.remove(root+'/'+folder+'/'+image)
                except:
                    pass

# Accessing all urls available for given input 
def find(chromedriver_path,query='flower'):
    global titles  # taking title and total_urls as global so interuption cannot affect retrieved urls 
    global total_urls
    browser=webdriver.Chrome(chromedriver_path)  # open webdriver file available in device for chrome
    browser.get('https://www.google.com/')
#   browser.fullscreen_window()
    search=browser.find_element_by_xpath('//*[@id="tsf"]/div[2]/div[1]/div[1]/div/div[2]/input')#google input automation
    search.send_keys(query+' image')
    time.sleep(1)
    search.send_keys(Keys.ENTER)
    time.sleep(1)
    browser.find_element_by_class_name('Q2MMlc').click()  # clicking so more results for input query on google images
    time.sleep(1)
#   Accessing image home page base
    titles.append('Home') # for home url 
    total_urls.append(list(set(images(browser)))) # appending all topics available on google 
    soup=BeautifulSoup(browser.page_source,'lxml') # scrapping all urls on home page
    titles.extend([link for link in soup.find_all('a',class_='F9PbJd IJRrpb xKddTc')])
    browser.close()
#   Accessing images topic based 
    for url in titles[1:]:  # for retriving all topics url 
        browser=webdriver.Chrome('./chromedriver')
        browser.get('https://www.google.com'+url['href'])
#       browser.fullscreen_window()
        time.sleep(1)
        total_urls.append(list(set(images(browser))))
        browser.close()
    print("Categories found : "+str(len(total_urls)))
    browser.close()


# In[8]:


def google_image(chromedriver_path,query):
    """Required chromedriver downloaded in the local device
    1 param: chromedriver_path
    2 query: image name 
    """
#     query=input()
    try:
        find(chromedriver_path,query)
    except:
        pass
    save_images(total_urls,titles,query)
    clean_garbage_files(query)
#google_image('Ascending triangle')


# In[ ]:





# In[ ]:





# In[ ]:





# In[3]:


# query='flower'
# browser=webdriver.Chrome('./chromedriver')
# browser.get('https://www.google.com/')
# search=browser.find_element_by_xpath('//*[@id="tsf"]/div[2]/div[1]/div[1]/div/div[2]/input')
# search.send_keys(query+' image')
# time.sleep(1)
# search.send_keys(Keys.ENTER)
# time.sleep(3)
# browser.find_element_by_class_name('Q2MMlc').click()
# time.sleep(3)
# soup=BeautifulSoup(browser.page_source,'lxml')
# titles=[link['href'] for link in soup.find_all('a',class_='F9PbJd IJRrpb xKddTc')]
# total_urls=[]
# for url in titles:
#     browser=webdriver.Chrome('./chromedriver')
#     browser.get('https://www.google.com'+url)
#     time.sleep(3)
#     total_urls.extend(images(browser))
#     browser.close()


# In[ ]:





# In[ ]:





# In[ ]:







"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com

"""
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC

from selenium import webdriver   
import imageio
import requests,os
from selenium.webdriver.common.keys import Keys  
from selenium.webdriver.support.select import Select
import time     
from bs4 import BeautifulSoup
import lxml
from PIL import Image
import urllib
import numpy as np
sleep_time=2

def searchByinputBox(browser,sleep_time,name='RELIANCE'):
    search=browser.find_element_by_class_name('input-3lfOzLDc')
    search.send_keys(Keys.CONTROL + "a")
    search.send_keys(name) 
    search.send_keys(Keys.ENTER)

def search_name(browser,sleep_time,name='RELIANCE'):#search_class:'input-3lfOzLDc'
    try:
        browser.find_element_by_xpath('//*[@id="header-toolbar-symbol-search"]/div/input').click()
        search=WebDriverWait(browser, 20).until(EC.element_to_be_clickable((By.CLASS_NAME, 'search-1t76YXcC')))
        browser.implicitly_wait(sleep_time)
        search.send_keys(Keys.CONTROL + "a") # select all text of input area to replace
        browser.implicitly_wait(sleep_time)
        search.send_keys(name) 
        search.send_keys(Keys.ENTER) # Enter to submit to search name of stock
    except:
        try:
            searchByinputBox(browser,sleep_time,name)
        except:
            browser.quit() 
#browser.implicitly_wait(sleep_time)

def period(browser,t='hour'):
    timet={'minute':8,'hour':16,'day':22,'week':23,'month':24}
    browser.implicitly_wait(sleep_time)
    element=WebDriverWait(browser, 20).until(EC.element_to_be_clickable((By.XPATH, '//*[@id="header-toolbar-intervals"]')))
    element.click()
    browser.implicitly_wait(sleep_time)
    browser.find_element_by_xpath('//*[@id="overlap-manager-root"]/div/span/div[1]/div/div/div/div[{}]/div/div[1]/div'.format(timet[t])).click()

def save_image(browser,name):
    if not os.path.exists('images'):
        os.makedirs('images')
    try:
        time.sleep(sleep_time)
        WebDriverWait(browser,20).until(EC.element_to_be_clickable((By.CLASS_NAME,'scrollRight-2SEqCpTf'))).click()
        time.sleep(sleep_time)
        browser.find_element_by_xpath('//*[@id="header-toolbar-screenshot"]/span').click()
        link=browser.find_element_by_xpath('//*[@id="overlap-manager-root"]/div/div/div[2]/div/div/div[1]/div[2]/div/div/div[2]/a')
        link.click()
        browser.switch_to.window(browser.window_handles[-1])
        url=browser.current_url
    except:
        browser.quit()
    print("image_url : ",url)
    image=Image.open(urllib.request.urlopen(url))
    image = Image.fromarray(np.array(image))
#     try:
    img_name='images/{}-{}.png'.format(name,len(os.listdir('images'))+1)
    image.save(img_name)
#     except:
#         image.save(img_name)
    browser.quit()
    return img_name    

        
def trade(chromedriver_path,name,t='month'):
    """
    Chromedriver must be downloaded into local device 
    1 chromedriver_path
    2 Stock symbol name ex:reliance,sbin,axisbank
    3: month,hour,week,minute
     
    """
    global sleep_time
    URL = 'https://tradingview.com/chart/'      
    browser = webdriver.Chrome(chromedriver_path) 
    browser.get(URL)
    #time.sleep(sleep_time)
    search_name(browser,sleep_time,name)
    period(browser,t='hour')
    img_name=save_image(browser,name)
    return img_name



"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

import requests 
from bs4 import BeautifulSoup 
def insta_post(url):
    URL=url
    print('Trying with : {}'.format(URL))
    text,image='',''
    with requests.Session() as session:
        r = requests.get(URL) 
        soup = BeautifulSoup(r.content, 'html.parser')
        json_data=soup.find('script',attrs={'type':"application/ld+json"})
        try:
            lst=list(json_data.children)
            lst=lst[0].replace('\n','').strip()
            json_=json.loads(lst)
#             print(json_)
            text=json_['caption']
            url=json_['mainEntityofPage']['@id']
        except:
            text=soup.title.text
        lst_str=soup.find('meta',attrs={'property':"og:image"})
        image=str(lst_str).split('" property="og:image"')[0].split('<meta content="')[1].strip().replace('amp;','')
    return text,image


# In[2]:


# url=input()
# Instagram_scrape(url)


# In[ ]:





# In[ ]:







"""
# Author Shivam Vishwakarma 
# sv6375261073@gmail.com
"""

from selenium import webdriver 
from selenium.webdriver.support.ui import WebDriverWait  
from selenium.webdriver.common.keys import Keys 
import time 


# In[4]:


def send_message(target,message,n=1):
    global driver
    input_block=driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[2]/div')
    for i in range(n):
        try:
            time.sleep(1)
            input_block.send_keys(Keys.CONTROL+'a')
            time.sleep(2)
            input_block.send_keys(message)
            send_button=driver.find_element_by_xpath('//*[@id="main"]/footer/div[1]/div[3]/button/span').click()
        except:
            time.sleep(1)


# In[ ]:



def whatsapp(chromedriver_path):
    """
    1 Chromedriver_path
    """
    driver = webdriver.Chrome(chromedriver_path) 
    driver.get("https://web.whatsapp.com/")
    agreement=input('did you scanned your web.whatsapp QR code y/n')
    if agreement =='y':
        while True:
            target=input("Enter receiver name : ")
            message=input("Enter message : ")
            n=int(input("Enter no. of time : "))
            try:
                time.sleep(2)
                search=driver.find_element_by_xpath('//*[@id="side"]/div[1]/div/label/div/div[2]')
                search.send_keys(target)
                time.sleep(2)
                search.send_keys(Keys.ENTER)
                send_message(target,message,n)
            except:
                print('receiver name does not exist in your contact ')
                try:
                    page=driver.current_url
                    print(target+" does not exist in your account ")
                except:
                    print('Web.whatsapp.com closed ')
                    return
#try:                    
#    start()
#except:
#    pass




